@@ -1,5 +1,5 @@
 package File::Update;
-$File::Update::VERSION = '0.0.2';
+$File::Update::VERSION = '0.0.3';
 use strict;
 use warnings;
 
@@ -57,7 +57,7 @@ File::Update - update/modify/mutate a file only on change in contents.
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -68,9 +68,24 @@ version 0.0.2
 
     write_on_change(path("dated-file.txt"), \$text);
 
+
+    use Path::Tiny qw/ path /;
+    use File::Update qw/ modify_on_change /;
+
+    foreach my $fn (@ARGV)
+    {
+        modify_on_change(
+            path($fn),
+            sub {
+                my $text = shift;
+                return $$text =~ s{\A#!/usr/bin/perl}{#!/usr/bin/env perl};
+            }
+        );
+    }
+
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 FUNCTIONS
 
